# Chem-I-Calc: The Chemical Information Calculator

Chem-I-Calc is a python package for evaluating the chemical information content
of resolved star spectroscopy.
It takes advantage of the Fisher information matrix and the Cramér-Rao inequality
to quickly calculate the Cramér-Rao lower bounds (CRLBs), which give the best
theoretically achievable precision from a set of observations.

## Authors
- Nathan Sandford (UC Berkeley, nathan_sandford@berkeley.edu)

## Collaborators
- Dan Weisz
- Yuan-Sen Ting

## Liscense & Attribution
Copyright 2019-2020 Nathan Sandford and contributors.

The source code is made available under the terms of the MIT license.

If you make use of this code, please cite Sandford et al. (In Press)